@@ -5,20 +5,27 @@ def countNans(df):
 
 
 def showStats(original_df, actual_df):
-    # NANS
-    print("Count of NANS in the raw dataset:")
-    print(countNans(original_df))
+    # Dataset information
+    print("*************************")
+    print("** DATASET INFORMATION **")
+    print("")
+    print("- Number of rows: " + str(len(actual_df)))
+    print("")
+    print("- Columns: " + actual_df.columns)
 
-    print(" ")
-    print("***********")
+    print("")
+    print("-------------------------")
+    print("DATASET STATISTICS")
+    print("")
+
+    # NANS
+    print("· Count of NANS in the raw dataset:")
+    print(countNans(original_df))
     print(" ")
 
     # Removed rows
-    print("Number of removed rows:")
+    print("· Number of removed rows:")
     print(len(original_df) - len(actual_df))
-
-    print(" ")
-    print("***********")
     print(" ")
 
 
